require "manual/version"

module Manual
  class Generator
    class << self
      def setup(config)
        config.before(:all) do
          Manual::Generator.init
        end

        config.after(:each, manual: :record) do |example|
          Manual::Generator.record(example, self)
        end

        config.after(:all) do
          Manual::Generator.render
        end
      end

      def init
        @pages = []
      end

      def render
        path = Rails.root.join("manual")
        Dir.mkdir(path) unless Dir.exists?(path)

        File.open(path.join("index.json"), 'w') do |file|
          file.write(@pages.to_json)
        end
      end

      def record(example, context)
        request = context.request
        response = context.response

        @pages << {
          scenario: {
            description: example.metadata[:description],
          },
          request: {
            method: request.method,
            path: request.path,
            params: request.params
          },
          response: {
            status: response.status,
            body: JSON.parse(response.body)
          }
        }
      end
    end
  end
end
